@@ -1,6 +1,6 @@
 package Test::Code::TidyAll;
 BEGIN {
-  $Test::Code::TidyAll::VERSION = '0.04';
+  $Test::Code::TidyAll::VERSION = '0.05';
 }
 use IPC::System::Simple qw(run);
 use Code::TidyAll;
@@ -45,14 +45,14 @@ tidyall
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
   In a file like 't/tidyall.t':
 
     #!/usr/bin/perl
-    use Test::TidyAll;
+    use Test::Code::TidyAll;
     tidyall_ok();
 
 =head1 DESCRIPTION
